/*
 * This file is part of JPuzzle.
 *
 * JPuzzle is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPuzzle is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JPuzzle.  If not, see <http://www.gnu.org/licenses/>.
 *
 * JPuzzle Copyright © 2008 HackmanGT
 * HackmanGT@hotmail.com
 */

package JPuzzle.Utilities;

import java.awt.image.BufferedImage;

/**
 * Las celdas son las unidades en que se divide el tablero de juego, contienen
 * el número ordinal que representan en el orden natural del tablero y
 * posiblemente una parte de la imagen.
 * @author HackmanGT
 */
public class Celda {

    private int valor;
    private BufferedImage imagen = null;

    /**
     * Construye una nueva celda con el valor por defecto 0 y una imagen null.
     */
    public Celda() {
        initComponents(0);
    }

    /**
     * Construye una nueva celda con el número indicado en el parámetro valor y
     * una imagen null.
     * @param valor el valor inicial de la celda
     */
    public Celda(int valor) {
        initComponents(valor);
    }

    /**
     * Inicializa el componente.
     * @param valor el valor inicial de la celda
     */
    private void initComponents(int valor) {
        this.setValor(valor);
    }

    /**
     * Devuelve el valor de la celda.
     * @return el valor de la celda
     */
    public int getValor() {
        return valor;
    }

    /**
     * Asigna un valor a la celda.
     * @param valor el valor de la celda
     */
    public void setValor(int valor) {
        this.valor = valor;
    }

    /**
     * Devuelve la imagen de la celda.
     * @return la imagen de la celda
     */
    public BufferedImage getImagen() {
        return imagen;
    }

    /**
     * Asigna una imagen a la celda.
     * @param imagen la imagen de la celda
     */
    public void setImagen(BufferedImage imagen) {
        this.imagen = imagen;
    }
}
